Crate legume

Crate legume 

Modules

ptr
Module for handling pointers.

Macros

call_conv

Enums

CallConv
An enum for the various calling conventions that Rust supports.

Traits

FnPtr
A trait for function pointers.
Freeze
Trait for types that contain no interior mutability, ignoring through indirection.
NoUninit
Trait for types that contain no uninitialized bytes.
NoUninitInOption
Trait for types that contain no uninitialized in an option.
Pointee
Trait for doing stuff with pointer metadata.
SafeFnPtr
A trait for function pointers that are always safe to call.
Thin
Trait for types that are accessed through thin pointers.
Zeroable
Trait for types that can be filled with all zeroes.
ZeroableExt
Trait that is automatically implemented for all Zeroable types, providing some
ZeroableInOption
Trait for types that when wrapped in an Option are zeroable.

Functions

bytes_of
fill_zeroes
Fill some T filled with all zeroes.
zeroed
Create a new T filled with all zeroes.